@@ -135,8 +135,13 @@ SEXP cl_Pam(SEXP k_, SEXP n_,
     }
 #endif
 
-    int i, nhalf = n * (n - 1) / 2 + 1; // nhalf := #{distances}+1 = length(dys)
+    int i, nhalf; // nhalf := #{distances}+1 = length(dys)
     double s;
+    if (n % 2 == 0) { // avoid overflow of n * (n - 1)
+	nhalf = n / 2 * (n - 1) + 1;
+    } else {
+	nhalf = (n - 1) / 2 * n + 1;
+    }
 
     int   *nsend = (int*) R_alloc(n, sizeof(int))
 	, *nelem = (int*) R_alloc(all_stats ? n : 1, sizeof(int)) /* Rboolean */
@@ -218,6 +223,7 @@ SEXP cl_Pam(SEXP k_, SEXP n_,
 	F77_CALL(dysta)((int*)&n, &p, x, dys, ndyst, jtmd, valmd, &jhalt);
 	if (jhalt != 0) {
 	    if(trace_lev) Rprintf(" dysta()-error: jhalt=%d\n", jhalt);
+	    UNPROTECT(nprot);
 	    return ScalarInteger(jhalt); // i.e., integer error code instead of a named list
 	}
 	// else
@@ -651,6 +657,7 @@ void cstat(int kk, int nn, int *nsend, int *nrepr, Rboolean all_stats,
 	if (kk == 1) {
 	    damer[1] = *s;
 	    nrepr[1] = nn;
+	    nisol[1] = 0;
 	    separ[1] = 0.;
 	    return;
 	}
